Empirical ROC curve
roc.curve.RdComputes the empirical ROC curve for a diagnostic tool.
Arguments
- marker
the marker values for each subject.
- status
binary disease status indicator
- method
the method for estimating the ROC curve. Currently only the empirical curve is implemented.
- x
object of class roc.curve output from this function.
- PRC
flag to tell whether ROC or Precision-Recall curve plotted.
- ...
optional arguments to the print, plot and lines functions.
Value
a list with the following elements
- marker
the diagnostic marker being studied.
- status
binary disease
- tpr
true positive rates for all thresholds.
- fpr
true positive rates for all thresholds.
- ppv
positive predictive values for all thresholds.
- npv
negative predictive values for all thresholds.
The "print" method returns the nonparametric AUC and its s.e.
The "plot" and "lines" methods can be used to draw a new plot and add to an existing plot of ROC curve.